@@ -78,6 +78,7 @@ pub struct Config {
     pub hunk_header_line_number_style: Style,
     pub hunk_header_style_include_file_path: HunkHeaderIncludeFilePath,
     pub hunk_header_style_include_line_number: HunkHeaderIncludeLineNumber,
+    pub hunk_header_style_include_code_fragment: HunkHeaderIncludeCodeFragment,
     pub hunk_header_style: Style,
     pub hunk_label: String,
     pub hyperlinks_commit_link_format: Option<String>,
@@ -151,6 +152,12 @@ pub enum HunkHeaderIncludeLineNumber {
     No,
 }
 
+#[cfg_attr(test, derive(Clone))]
+pub enum HunkHeaderIncludeCodeFragment {
+    Yes,
+    No,
+}
+
 impl Config {
     pub fn get_style(&self, state: &State) -> &Style {
         match state {
@@ -331,6 +338,15 @@ impl From<cli::Opt> for Config {
             } else {
                 HunkHeaderIncludeLineNumber::No
             },
+            hunk_header_style_include_code_fragment: if opt
+                .hunk_header_style
+                .split(' ')
+                .any(|s| s == "omit-code-fragment")
+            {
+                HunkHeaderIncludeCodeFragment::No
+            } else {
+                HunkHeaderIncludeCodeFragment::Yes
+            },
             hyperlinks: opt.hyperlinks,
             hyperlinks_commit_link_format: opt.hyperlinks_commit_link_format,
             hyperlinks_file_link_format: opt.hyperlinks_file_link_format,
@@ -468,9 +484,9 @@ pub mod tests {
             Some(git_config_contents),
             Some(git_config_path),
         );
-        assert_eq!(config.true_color, false);
+        assert!(!config.true_color);
         assert_eq!(config.decorations_width, cli::Width::Fixed(100));
-        assert_eq!(config.background_color_extends_to_terminal_width, true);
+        assert!(config.background_color_extends_to_terminal_width);
         assert_eq!(config.inspect_raw_lines, cli::InspectRawLines::True);
         assert_eq!(config.paging_mode, PagingMode::Never);
         assert!(config.syntax_theme.is_none());
